/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSlice.h"
#include "HvSignalLine.h"
#include "HvControlIf.h"
#include "HvMath.h"
#include "HvControlUnop.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvSignalBiquad.h"
#include "HvControlSystem.h"
#include "HvControlCast.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_jfrtnOcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IMR3H7Na_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vtSy6wkZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1MtWumcq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_FDgSEzX9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_q4M7lqmQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_E3GHwlih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IlOGYo3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_v1gPC14f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jXkw23TC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xrOmesSp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qr3bW50C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ltKaGWx8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C55KkHdG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fkp1glzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f4OV2zQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zlYEXmCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qlt901Pv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fkYLArcn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CswkOgFD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uMjuheIM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vU1YdayI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8z3tGjPG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OQlGRDHa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Id7mJvNd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7Cs4t5yp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FFv4Ln29_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jCSviFoJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JGjazFsK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nnrBAPU2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PTktNDQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UJUM10UO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_majzE7Jd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZJQF48kd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iSTtLRFv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vd918Vzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dMO9kBnl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yhjd5k4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xiFwJol9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_54IOLCxB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_md6VheIi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QNtLfLDQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P8Q2HXpV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SNwc2YXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m1xhXQOD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xZkfSfhp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Or2Jn0uW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ohOq4NCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bVwB3yXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E6Hm4A2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U13FgygP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XhmCYikg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D5yZGYnV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Hllte5Ji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_s7TeOLfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kT6dfG4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nzIZIMff_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xX8SjVIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NhNXhD8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_keUlqVr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uD38lxc9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GUNo00M4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HR0bqPgL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nWHELEnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xrCi1UqH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8plgATOp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tjyBEVR2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YORlybOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_10bsZcHN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7SSIlkvO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cAVDy5II_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OQ7VETJl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gym5ehSH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qZTFOet4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EXNZ7nCk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nAnAPA9W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nf3xSnxJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dI4Lc73Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NVp7adt5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8TuSeklC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZlpDwMUO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Mmjf8fah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_W0grdQMj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_GcYg8prd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xnnLly9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BnET3vBI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pqmi75R7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DgRpcv9a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2QfDry4G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fTcprviX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4z2rXq2H_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_5n7kabDQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_et2FBjua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JtFj4tCG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_idebMecT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fvfwvqrx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k45sSNit_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q6crkC3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fK6rQSbL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jAI0jrq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uCdENDAN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jpcGnX86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EONN58bQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_krkuEvX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2S1bPDHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7TLfyVNP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CMIBNTVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_O2ET0YF3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LRhU6mv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lQwClNeZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mt9dfKVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gjEWr5lh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bvjCXTtJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lq66MIS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_khda2Ght_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pH3UXkH3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iy2gA8Xv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ITd5WI4C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UpvavH0W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jmLkgnGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ENHOryIr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O8KKQwcY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FDzdNmhW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YktVAC59_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_etzAW6EM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FQqxHGgV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d7041uNJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4F1P11CV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rexTbIL7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Q4YS0JTo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_A3JIAblZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jUiXXMez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_buSE3b9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SpV57ZQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P0kXceBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_swKtxsuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Uc3vcto_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CmJxodvk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sk2op25q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9VBG93U6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7WjoZOpx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gzt10Ao6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CrO7uqYI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kGbYcZAZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A0HI5tSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z3k9fFh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iqaduyrW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6yb7jjyh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qjNwzjHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7CH7fHYp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xgQ93EDV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z82hKKgx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P5fnWNyc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QDYsYAAX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_62R2wbQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xlz3gntb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MGokEdL4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7fOuGwHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Yt0rhTnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bLbdPYir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FILC9uU7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uyyrqYaL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_crBw0bnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dUVwLzvD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_secaQRzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QqgnnLWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WaVctxhE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_giAdiM5y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XZZe0wyD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QD3eM94G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6m3uOaw2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B7Qc1UjA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1pbYYinU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nUQHPKKK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d6r5YQHc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tMIBNR3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_L2id6emV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_U3dGxJfH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_06b5P3nP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4f2RkoVG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_uDTD82kq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IWBr5ibq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oYPnXQr2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QpfYTHMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FSIGXJWd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xJnB2QRp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gWFEEBDO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_APUTx5MC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eFwvzZQC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_INWutskc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K0INi9UX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u7XMnkYM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i3mLVp5z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zrqnLco2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NjwCCN6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SVDBrXrW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A9cjyHKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SCujQoFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XZ68gUhK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cmg14sbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GAnSHE9Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1euoV2DZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VoVQ8Yan_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hUFHPVkH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H7or9t4J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ncUVaDPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_32oSRPDv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_N9ALtUlu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_7FGrHqYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MZzJTL8m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iDTWjrLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0OfiC5bZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xKy9FOUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TWFxChhw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_F49U3vf0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_UxBPDM8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BBbX5NxD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_20gJUaNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i0puDkdH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aWIfLLrA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EIt07BVE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FQFAjXtx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ayeaAQ3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ai23OoXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FLQYtzGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pA9lTJNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GbQbBNXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QLswgAjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_moTOubIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bduJ7KAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4zuTdMwd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oO3kzX87_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vd4VUsJp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tC7fUeIo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SoxXjte3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_beLnNjvR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GzCMn6UA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nNqtzkqL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_TMKIOnlx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fA0LUSLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XTJgmyKK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4umwPkI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CbbwbT1e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NKapEe9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L9tGKxsY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PHbWjzve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TnIowIoc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nU9AsKmA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H7DA8Qis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o2w1dbFi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uHhLH2aK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kbSKxFmv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ovdKNu6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A8yRfwGW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lCIfaQED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pU6DdxcX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qWHvs2z5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4Rl8fp5h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mWGnlhar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3wmz1SiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AmCcAaTO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vWwvK8fn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M2A2Sodc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8fe05WD0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eI5I2hpm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qmBjRVvS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zvAokxWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KFVl6SEg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_l1ElyRjt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dgAc46fG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CtyiGwaG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SOVtvV7d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O7TlN3HM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GSdjPg12_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nC9o58EL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w0Ao3nDK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b2j5MzNx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8vfNZH0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vLC05DEs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XrbdxU1E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ioSIzLTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6fl6phwV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gakPBCgQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FEONa8WA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ORPtmvlS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AFwjZcIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EGOomR1e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3sjsYxHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_250ukhWh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WwCMK3Gn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_atiZzxyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eCZ1PFyU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ygntg97b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GiKHy4o7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_I42wFhWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_03J9eIiG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HsNN0I4K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uoxwkjgf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9caMjFHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Zh5vYzs3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MaFGW02v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0HOPMHBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZFJflXpe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cb54gLE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_y9spU39M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MxhXmjev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MX86cLdv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fjoDXAu7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZqSuPk45_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7B106cjZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wy1eugEB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U93HEhwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_62oNFfr7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PfK78pLU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hGM9tyTG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mVYKX3jp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VMoPfwB5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iwEqScJK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cnZ5UKBB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y7uzRiSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HehK2ANx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KQh4lw8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cmUMBFnh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BpVk2C7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EYPVVvnD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VA7lzOIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_imAc98aq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jnXuDYfn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0nDl6kXL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nvYEeXz4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G9cLReVw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OEcMKIBj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CLCbIvON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xmbcsy4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zav9fxLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CXC0BSL8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MO5oYF1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JnscY0Y6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_l5anHsjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HhvlsgjL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ke3srxSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_U0QWk7PT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NCPV5pZt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sImdb2Hk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4mlt9kw3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7NQir8aM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0hLecjms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oPjUgda6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ACRsowVX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GOoMHg8L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0xKSLa5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hHkXcHIe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_k9TPkZbD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FJZx45m5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZuhBDs4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dBbuB78I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Tb9pL39I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y6Kzl7E2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K9RADPir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GlxxXo5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MqrbNxT4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rrAYlWcd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lteRSIEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZlnBulJI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SiSAUPl6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bKhO4fwp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XiBw2PBL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VD5ssbf2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_zlgEpUxT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_cRb4ILvt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bVouPOP5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GZHerVWn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fBAR8Ii0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_35QRjtTk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_stbcqS61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ByjtPJog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gl4bfnMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ycc6tomW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_capsYWxP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TA64u9gh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EkWpuMg6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ckbYcVp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ktSEtU1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CcFAI29p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_INF2FBD9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NIZqKC1c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HwRJ1aDg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5bANUX6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K0tt5Wnr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_8h94Flat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_w7F3X9x6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yPR6Stxt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mNdFbusj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_66aFzDdZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yCUyJSQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p0AjcL12_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uVfoupSk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k6MYXm2O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tdzSXxSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_02BR6lAt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tCS4U6gc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yHJWSt6d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SSMGvCb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Pesfzccl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i8Pt1SJM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rJ85iH4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mWhxHnn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dNFOE809_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dEyEwGFA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ODjsWRFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZmMLDM8A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cu2COhpg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZEW0bWGs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YZh0Kmnz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7iPHrejT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8wv8KbtI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iu8kA44Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0U5Uvbbn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ikQiaKMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9hwDtK0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_um7gNDnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tr6qCWIU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oLcOuNlf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JuMSppCj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_02vzkJVe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_mZ79iVZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_EiqdLhT3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xciwzv7h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4NJQhQdD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TSuk7cj9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_miiK83JW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jWiuul9q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xCGgI05F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z14f1Wwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TXl0zLry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rgQrqDbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hG3f0wug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DaXKJt2d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LqfOrDu2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ow7QsCT4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TdvyTqFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_8FTnTKKJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_v3j1xT2L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UrI3RKDL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hFxIA5lf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D2xGOGSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_phB9ZDEA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IJrTRWna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BZJ2CChK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XuUzuch6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mOEkGuLK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TOIYivRy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WGCSsTmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bK0pmqi9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZhTl5Fug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CE9RUrmo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VocsINDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KTN7GPoD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Hv6WGFQZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6UATYqFO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xXN3zRjW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pYZNAeCj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vTSlJwm2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xR2RKm1u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FgIJLMD9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wiaCCwJx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7kuz2zLF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EDcSgDv2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eULLxysw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_F4UKxYL7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FkscCLZz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lw5LmAPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YgKxeW3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gdELYuNf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bb5qhsIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_eKk1Uico_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_q1fcAhca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eeq8eQVv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_plaewexW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uH1Gxf1Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_agHuH878_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1iuS0bHR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gT1t5upF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yXFh3gHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fmSONCWy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BFDzG0LA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ek5nvA9W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AROAhBMh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6IUiQruK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dQ6DwjfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_knesFkqU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ys9OqKuB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iOZZKIkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PXg4fyYM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gDiVGir5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_S0By4Jqe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O1XTyP3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_886OKzES_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_uyy1Tyta_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_HFdZf353_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bfFuXP4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gugqqsJA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KAXymB8C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w0ZxiVXu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2WeLuBUw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vbvV8ZF6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rQ82WhbN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xI7GsVzV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cPU4Gu3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1LQXGraR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O4b1KXbR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LWUjxRnD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DRCH1TIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5ItroLvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hPe3tkSD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v3hgfL1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n07UuKRB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P7H64pH4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mzQZW0L6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TyOEYjmb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ANInhJMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hGPAF5Fw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9D42Yqs5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2GdB483E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x3QjB3fx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mkGQinJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_seZ4LRQs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dipkrxb6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_A0a0yoqp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_hjW7Bwwe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BY9xw4Us_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yFCE4lmN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xl8n3231_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YUml3XsY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qu3FEt5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9810lrn0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_k6bmhCfZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FWSvJYEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HSt5BbNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GIGQRKc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JpFwX6hb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xrnNQ4bm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lIYO0Ygn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jlDRREMS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hFh2LvOU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_REYmMQKz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E6qekZAK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zwqjnwvD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2qoPdLQh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OOkM9S0f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ufrh7REf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TjoXp7oL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fS9RpQGy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Gm9xtO86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lXPujBcf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pd1IpMrk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vUv9XndB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Alvr9y2c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hRcu0yqk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7qKqy3Iu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VNpjjg3m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vV7hKqs3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fjANCDGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sC2C6G0n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Sy27vxn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_igeKPSNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aRZYEWOw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Am2L00Y4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZaU7LVji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sEfNHEeb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WYBQJFSY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_B0WlwGFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bHLJvoCh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vw5uMln7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_p3juSIWg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CWQtMage_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7HwlqILa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_X8aYjjuO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5cuq9JvA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lmudNx7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R8fFkXLC_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_eKj6bdJF;
  SignalLine sLine_14I7RrTz;
  SignalLine sLine_cR2N2yCy;
  SignalLine sLine_2nbteVhx;
  SignalLine sLine_gGs7ipS6;
  SignalBiquad sBiquad_s_foWA1e5C;
  SignalLine sLine_TWv9oRcT;
  SignalLine sLine_P1kzTLzC;
  SignalLine sLine_NtA2PzBy;
  SignalLine sLine_JsrjmH9I;
  SignalBiquad sBiquad_s_sVBgBtvZ;
  SignalLine sLine_Bx84acVu;
  SignalLine sLine_ytgdm7By;
  SignalLine sLine_aSzyrf1s;
  SignalLine sLine_8NJ3W0zf;
  SignalLine sLine_gfUZVFTq;
  SignalBiquad sBiquad_s_gEY0feeB;
  SignalLine sLine_8I98kIm3;
  SignalLine sLine_lT7m5H5x;
  SignalLine sLine_y3QPCsBr;
  SignalLine sLine_JRLhhLr5;
  SignalLine sLine_yatRxkAG;
  SignalBiquad sBiquad_s_HCG84Bua;
  SignalLine sLine_pbb7uhuO;
  SignalLine sLine_hxjV1MJ2;
  SignalLine sLine_KCcQEVnn;
  SignalLine sLine_YDsfVvJx;
  SignalBiquad sBiquad_s_115TrxA1;
  SignalLine sLine_eiEWm6Dn;
  SignalLine sLine_kfjRbi8m;
  SignalLine sLine_TkWBQdA2;
  SignalLine sLine_HgB6s6ph;
  SignalLine sLine_0Cl4HVxr;
  SignalBiquad sBiquad_s_dRi47Cya;
  ControlVar cVar_jfrtnOcP;
  ControlVar cVar_IMR3H7Na;
  ControlVar cVar_vtSy6wkZ;
  ControlVar cVar_1MtWumcq;
  ControlSlice cSlice_q4M7lqmQ;
  ControlVar cVar_E3GHwlih;
  ControlVar cVar_v1gPC14f;
  ControlIf cIf_jXkw23TC;
  ControlIf cIf_xrOmesSp;
  ControlBinop cBinop_ltKaGWx8;
  ControlBinop cBinop_C55KkHdG;
  ControlBinop cBinop_zlYEXmCJ;
  ControlBinop cBinop_qlt901Pv;
  ControlBinop cBinop_CswkOgFD;
  ControlIf cIf_uMjuheIM;
  ControlBinop cBinop_vU1YdayI;
  ControlBinop cBinop_8z3tGjPG;
  ControlBinop cBinop_Id7mJvNd;
  ControlBinop cBinop_7Cs4t5yp;
  ControlBinop cBinop_FFv4Ln29;
  ControlVar cVar_UJUM10UO;
  ControlIf cIf_majzE7Jd;
  ControlIf cIf_ZJQF48kd;
  ControlBinop cBinop_Vd918Vzh;
  ControlBinop cBinop_dMO9kBnl;
  ControlBinop cBinop_54IOLCxB;
  ControlBinop cBinop_md6VheIi;
  ControlBinop cBinop_P8Q2HXpV;
  ControlIf cIf_SNwc2YXi;
  ControlBinop cBinop_m1xhXQOD;
  ControlBinop cBinop_xZkfSfhp;
  ControlBinop cBinop_ohOq4NCJ;
  ControlBinop cBinop_bVwB3yXi;
  ControlBinop cBinop_E6Hm4A2S;
  ControlVar cVar_s7TeOLfD;
  ControlIf cIf_kT6dfG4q;
  ControlIf cIf_nzIZIMff;
  ControlBinop cBinop_NhNXhD8G;
  ControlBinop cBinop_keUlqVr6;
  ControlBinop cBinop_HR0bqPgL;
  ControlBinop cBinop_nWHELEnd;
  ControlBinop cBinop_8plgATOp;
  ControlIf cIf_tjyBEVR2;
  ControlBinop cBinop_YORlybOH;
  ControlBinop cBinop_10bsZcHN;
  ControlBinop cBinop_cAVDy5II;
  ControlBinop cBinop_OQ7VETJl;
  ControlBinop cBinop_Gym5ehSH;
  ControlIf cIf_dI4Lc73Q;
  ControlSlice cSlice_8TuSeklC;
  ControlVar cVar_ZlpDwMUO;
  ControlSlice cSlice_GcYg8prd;
  ControlVar cVar_xnnLly9b;
  ControlSlice cSlice_DgRpcv9a;
  ControlVar cVar_2QfDry4G;
  ControlSlice cSlice_5n7kabDQ;
  ControlVar cVar_et2FBjua;
  ControlBinop cBinop_krkuEvX2;
  ControlBinop cBinop_7TLfyVNP;
  ControlBinop cBinop_CMIBNTVT;
  ControlBinop cBinop_lQwClNeZ;
  ControlBinop cBinop_Mt9dfKVQ;
  ControlBinop cBinop_gjEWr5lh;
  ControlBinop cBinop_bvjCXTtJ;
  ControlBinop cBinop_Lq66MIS1;
  ControlVar cVar_khda2Ght;
  ControlBinop cBinop_pH3UXkH3;
  ControlBinop cBinop_iy2gA8Xv;
  ControlBinop cBinop_ITd5WI4C;
  ControlBinop cBinop_UpvavH0W;
  ControlBinop cBinop_jmLkgnGq;
  ControlBinop cBinop_ENHOryIr;
  ControlBinop cBinop_O8KKQwcY;
  ControlBinop cBinop_YktVAC59;
  ControlVar cVar_etzAW6EM;
  ControlVar cVar_FQqxHGgV;
  ControlBinop cBinop_buSE3b9U;
  ControlBinop cBinop_SpV57ZQL;
  ControlBinop cBinop_P0kXceBl;
  ControlBinop cBinop_8Uc3vcto;
  ControlBinop cBinop_CmJxodvk;
  ControlBinop cBinop_Sk2op25q;
  ControlBinop cBinop_9VBG93U6;
  ControlBinop cBinop_7WjoZOpx;
  ControlBinop cBinop_Gzt10Ao6;
  ControlBinop cBinop_FILC9uU7;
  ControlBinop cBinop_crBw0bnK;
  ControlBinop cBinop_dUVwLzvD;
  ControlBinop cBinop_WaVctxhE;
  ControlBinop cBinop_giAdiM5y;
  ControlBinop cBinop_XZZe0wyD;
  ControlBinop cBinop_QD3eM94G;
  ControlBinop cBinop_6m3uOaw2;
  ControlBinop cBinop_B7Qc1UjA;
  ControlBinop cBinop_1pbYYinU;
  ControlBinop cBinop_d6r5YQHc;
  ControlVar cVar_tMIBNR3g;
  ControlVar cVar_L2id6emV;
  ControlVar cVar_U3dGxJfH;
  ControlBinop cBinop_FSIGXJWd;
  ControlBinop cBinop_xJnB2QRp;
  ControlBinop cBinop_gWFEEBDO;
  ControlBinop cBinop_eFwvzZQC;
  ControlBinop cBinop_INWutskc;
  ControlBinop cBinop_K0INi9UX;
  ControlBinop cBinop_u7XMnkYM;
  ControlBinop cBinop_i3mLVp5z;
  ControlBinop cBinop_iDTWjrLS;
  ControlBinop cBinop_xKy9FOUE;
  ControlBinop cBinop_TWFxChhw;
  ControlBinop cBinop_BBbX5NxD;
  ControlBinop cBinop_20gJUaNR;
  ControlBinop cBinop_i0puDkdH;
  ControlBinop cBinop_aWIfLLrA;
  ControlBinop cBinop_EIt07BVE;
  ControlBinop cBinop_ayeaAQ3f;
  ControlBinop cBinop_FLQYtzGD;
  ControlBinop cBinop_pA9lTJNq;
  ControlBinop cBinop_QLswgAjG;
  ControlBinop cBinop_moTOubIc;
  ControlBinop cBinop_bduJ7KAs;
  ControlBinop cBinop_oO3kzX87;
  ControlVar cVar_vd4VUsJp;
  ControlVar cVar_tC7fUeIo;
  ControlVar cVar_SoxXjte3;
  ControlBinop cBinop_4umwPkI1;
  ControlBinop cBinop_CbbwbT1e;
  ControlBinop cBinop_NKapEe9o;
  ControlBinop cBinop_PHbWjzve;
  ControlBinop cBinop_TnIowIoc;
  ControlBinop cBinop_nU9AsKmA;
  ControlBinop cBinop_H7DA8Qis;
  ControlBinop cBinop_o2w1dbFi;
  ControlBinop cBinop_uHhLH2aK;
  ControlBinop cBinop_vWwvK8fn;
  ControlBinop cBinop_8fe05WD0;
  ControlBinop cBinop_eI5I2hpm;
  SignalVarf sVarf_wNoIBwKQ;
  SignalVarf sVarf_Zs78BUNw;
  SignalVarf sVarf_flWJofjf;
  ControlSlice cSlice_zvAokxWU;
  ControlVar cVar_KFVl6SEg;
  ControlVar cVar_dgAc46fG;
  ControlIf cIf_CtyiGwaG;
  ControlIf cIf_SOVtvV7d;
  ControlBinop cBinop_GSdjPg12;
  ControlBinop cBinop_nC9o58EL;
  ControlBinop cBinop_8vfNZH0F;
  ControlBinop cBinop_vLC05DEs;
  ControlBinop cBinop_ioSIzLTZ;
  ControlIf cIf_6fl6phwV;
  ControlBinop cBinop_gakPBCgQ;
  ControlBinop cBinop_FEONa8WA;
  ControlBinop cBinop_AFwjZcIk;
  ControlBinop cBinop_EGOomR1e;
  ControlBinop cBinop_3sjsYxHd;
  ControlVar cVar_ygntg97b;
  ControlIf cIf_GiKHy4o7;
  ControlIf cIf_I42wFhWN;
  ControlBinop cBinop_HsNN0I4K;
  ControlBinop cBinop_Uoxwkjgf;
  ControlBinop cBinop_MaFGW02v;
  ControlBinop cBinop_0HOPMHBO;
  ControlBinop cBinop_cb54gLE6;
  ControlIf cIf_y9spU39M;
  ControlBinop cBinop_MxhXmjev;
  ControlBinop cBinop_MX86cLdv;
  ControlBinop cBinop_ZqSuPk45;
  ControlBinop cBinop_7B106cjZ;
  ControlBinop cBinop_wy1eugEB;
  ControlVar cVar_mVYKX3jp;
  ControlIf cIf_VMoPfwB5;
  ControlIf cIf_iwEqScJK;
  ControlBinop cBinop_Y7uzRiSg;
  ControlBinop cBinop_HehK2ANx;
  ControlBinop cBinop_BpVk2C7y;
  ControlBinop cBinop_EYPVVvnD;
  ControlBinop cBinop_imAc98aq;
  ControlIf cIf_jnXuDYfn;
  ControlBinop cBinop_0nDl6kXL;
  ControlBinop cBinop_nvYEeXz4;
  ControlBinop cBinop_OEcMKIBj;
  ControlBinop cBinop_CLCbIvON;
  ControlBinop cBinop_Xmbcsy4W;
  ControlIf cIf_l5anHsjp;
  ControlSlice cSlice_ke3srxSC;
  ControlVar cVar_U0QWk7PT;
  ControlSlice cSlice_4mlt9kw3;
  ControlVar cVar_7NQir8aM;
  ControlSlice cSlice_ACRsowVX;
  ControlVar cVar_GOoMHg8L;
  ControlSlice cSlice_k9TPkZbD;
  ControlVar cVar_FJZx45m5;
  ControlBinop cBinop_SiSAUPl6;
  ControlBinop cBinop_XiBw2PBL;
  ControlBinop cBinop_VD5ssbf2;
  ControlBinop cBinop_bVouPOP5;
  ControlBinop cBinop_GZHerVWn;
  ControlBinop cBinop_fBAR8Ii0;
  ControlBinop cBinop_35QRjtTk;
  ControlBinop cBinop_stbcqS61;
  ControlVar cVar_ByjtPJog;
  ControlBinop cBinop_gl4bfnMs;
  ControlBinop cBinop_Ycc6tomW;
  ControlBinop cBinop_capsYWxP;
  ControlBinop cBinop_TA64u9gh;
  ControlBinop cBinop_EkWpuMg6;
  ControlBinop cBinop_ckbYcVp6;
  ControlBinop cBinop_ktSEtU1z;
  ControlBinop cBinop_INF2FBD9;
  ControlVar cVar_NIZqKC1c;
  ControlVar cVar_HwRJ1aDg;
  ControlBinop cBinop_66aFzDdZ;
  ControlBinop cBinop_yCUyJSQT;
  ControlBinop cBinop_p0AjcL12;
  ControlBinop cBinop_k6MYXm2O;
  ControlBinop cBinop_tdzSXxSi;
  ControlBinop cBinop_02BR6lAt;
  ControlBinop cBinop_tCS4U6gc;
  ControlBinop cBinop_yHJWSt6d;
  ControlBinop cBinop_SSMGvCb3;
  ControlBinop cBinop_tr6qCWIU;
  ControlBinop cBinop_JuMSppCj;
  ControlBinop cBinop_02vzkJVe;
  ControlBinop cBinop_xciwzv7h;
  ControlBinop cBinop_4NJQhQdD;
  ControlBinop cBinop_TSuk7cj9;
  ControlBinop cBinop_miiK83JW;
  ControlBinop cBinop_jWiuul9q;
  ControlBinop cBinop_xCGgI05F;
  ControlBinop cBinop_z14f1Wwg;
  ControlBinop cBinop_rgQrqDbl;
  ControlVar cVar_hG3f0wug;
  ControlVar cVar_DaXKJt2d;
  ControlVar cVar_LqfOrDu2;
  ControlBinop cBinop_D2xGOGSg;
  ControlBinop cBinop_phB9ZDEA;
  ControlBinop cBinop_IJrTRWna;
  ControlBinop cBinop_XuUzuch6;
  ControlBinop cBinop_mOEkGuLK;
  ControlBinop cBinop_TOIYivRy;
  ControlBinop cBinop_WGCSsTmw;
  ControlBinop cBinop_bK0pmqi9;
  ControlBinop cBinop_lw5LmAPw;
  ControlBinop cBinop_gdELYuNf;
  ControlBinop cBinop_bb5qhsIv;
  ControlBinop cBinop_eeq8eQVv;
  ControlBinop cBinop_plaewexW;
  ControlBinop cBinop_uH1Gxf1Q;
  ControlBinop cBinop_agHuH878;
  ControlBinop cBinop_1iuS0bHR;
  ControlBinop cBinop_yXFh3gHg;
  ControlBinop cBinop_BFDzG0LA;
  ControlBinop cBinop_ek5nvA9W;
  ControlBinop cBinop_6IUiQruK;
  ControlBinop cBinop_dQ6DwjfU;
  ControlBinop cBinop_knesFkqU;
  ControlBinop cBinop_iOZZKIkP;
  ControlVar cVar_PXg4fyYM;
  ControlVar cVar_gDiVGir5;
  ControlVar cVar_S0By4Jqe;
  ControlBinop cBinop_KAXymB8C;
  ControlBinop cBinop_w0ZxiVXu;
  ControlBinop cBinop_2WeLuBUw;
  ControlBinop cBinop_rQ82WhbN;
  ControlBinop cBinop_xI7GsVzV;
  ControlBinop cBinop_cPU4Gu3C;
  ControlBinop cBinop_1LQXGraR;
  ControlBinop cBinop_O4b1KXbR;
  ControlBinop cBinop_LWUjxRnD;
  ControlBinop cBinop_9D42Yqs5;
  ControlBinop cBinop_x3QjB3fx;
  ControlBinop cBinop_mkGQinJ5;
  SignalVarf sVarf_UujXhb5A;
  SignalVarf sVarf_UQ6Z4jbl;
  SignalVarf sVarf_zixa8m1v;
  ControlVar cVar_seZ4LRQs;
  ControlVar cVar_dipkrxb6;
  ControlBinop cBinop_YUml3XsY;
  ControlBinop cBinop_qu3FEt5P;
  ControlBinop cBinop_9810lrn0;
  ControlBinop cBinop_FWSvJYEO;
  ControlBinop cBinop_HSt5BbNR;
  ControlBinop cBinop_GIGQRKc3;
  ControlBinop cBinop_JpFwX6hb;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
