/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_eKj6bdJF);
  numBytes += sLine_init(&sLine_14I7RrTz);
  numBytes += sLine_init(&sLine_cR2N2yCy);
  numBytes += sLine_init(&sLine_2nbteVhx);
  numBytes += sLine_init(&sLine_gGs7ipS6);
  numBytes += sBiquad_init(&sBiquad_s_foWA1e5C);
  numBytes += sLine_init(&sLine_TWv9oRcT);
  numBytes += sLine_init(&sLine_P1kzTLzC);
  numBytes += sLine_init(&sLine_NtA2PzBy);
  numBytes += sLine_init(&sLine_JsrjmH9I);
  numBytes += sBiquad_init(&sBiquad_s_sVBgBtvZ);
  numBytes += sLine_init(&sLine_Bx84acVu);
  numBytes += sLine_init(&sLine_ytgdm7By);
  numBytes += sLine_init(&sLine_aSzyrf1s);
  numBytes += sLine_init(&sLine_8NJ3W0zf);
  numBytes += sLine_init(&sLine_gfUZVFTq);
  numBytes += sBiquad_init(&sBiquad_s_gEY0feeB);
  numBytes += sLine_init(&sLine_8I98kIm3);
  numBytes += sLine_init(&sLine_lT7m5H5x);
  numBytes += sLine_init(&sLine_y3QPCsBr);
  numBytes += sLine_init(&sLine_JRLhhLr5);
  numBytes += sLine_init(&sLine_yatRxkAG);
  numBytes += sBiquad_init(&sBiquad_s_HCG84Bua);
  numBytes += sLine_init(&sLine_pbb7uhuO);
  numBytes += sLine_init(&sLine_hxjV1MJ2);
  numBytes += sLine_init(&sLine_KCcQEVnn);
  numBytes += sLine_init(&sLine_YDsfVvJx);
  numBytes += sBiquad_init(&sBiquad_s_115TrxA1);
  numBytes += sLine_init(&sLine_eiEWm6Dn);
  numBytes += sLine_init(&sLine_kfjRbi8m);
  numBytes += sLine_init(&sLine_TkWBQdA2);
  numBytes += sLine_init(&sLine_HgB6s6ph);
  numBytes += sLine_init(&sLine_0Cl4HVxr);
  numBytes += sBiquad_init(&sBiquad_s_dRi47Cya);
  numBytes += cVar_init_f(&cVar_jfrtnOcP, 0.0f);
  numBytes += cVar_init_f(&cVar_IMR3H7Na, 0.0f);
  numBytes += cVar_init_f(&cVar_vtSy6wkZ, 0.0f);
  numBytes += cVar_init_f(&cVar_1MtWumcq, 0.0f);
  numBytes += cSlice_init(&cSlice_q4M7lqmQ, 1, -1);
  numBytes += cVar_init_f(&cVar_E3GHwlih, 1337.0f);
  numBytes += cVar_init_f(&cVar_v1gPC14f, 0.0f);
  numBytes += cIf_init(&cIf_jXkw23TC, false);
  numBytes += cIf_init(&cIf_xrOmesSp, false);
  numBytes += cBinop_init(&cBinop_ltKaGWx8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_uMjuheIM, false);
  numBytes += cBinop_init(&cBinop_Id7mJvNd, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_7Cs4t5yp, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_FFv4Ln29, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_UJUM10UO, 0.0f);
  numBytes += cIf_init(&cIf_majzE7Jd, false);
  numBytes += cIf_init(&cIf_ZJQF48kd, false);
  numBytes += cBinop_init(&cBinop_Vd918Vzh, 0.0f); // __pow
  numBytes += cIf_init(&cIf_SNwc2YXi, false);
  numBytes += cBinop_init(&cBinop_ohOq4NCJ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_bVwB3yXi, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_E6Hm4A2S, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_s7TeOLfD, 0.0f);
  numBytes += cIf_init(&cIf_kT6dfG4q, false);
  numBytes += cIf_init(&cIf_nzIZIMff, false);
  numBytes += cBinop_init(&cBinop_NhNXhD8G, 0.0f); // __pow
  numBytes += cIf_init(&cIf_tjyBEVR2, false);
  numBytes += cBinop_init(&cBinop_cAVDy5II, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_OQ7VETJl, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Gym5ehSH, -15.0f); // __eq
  numBytes += cIf_init(&cIf_dI4Lc73Q, false);
  numBytes += cSlice_init(&cSlice_8TuSeklC, 1, -1);
  numBytes += cVar_init_f(&cVar_ZlpDwMUO, 0.0f);
  numBytes += cSlice_init(&cSlice_GcYg8prd, 1, -1);
  numBytes += cVar_init_f(&cVar_xnnLly9b, 0.0f);
  numBytes += cSlice_init(&cSlice_DgRpcv9a, 1, -1);
  numBytes += cVar_init_f(&cVar_2QfDry4G, 0.0f);
  numBytes += cSlice_init(&cSlice_5n7kabDQ, 1, -1);
  numBytes += cVar_init_f(&cVar_et2FBjua, 0.313f);
  numBytes += cBinop_init(&cBinop_7TLfyVNP, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_CMIBNTVT, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_khda2Ght, 0.0f);
  numBytes += cVar_init_f(&cVar_etzAW6EM, 1337.0f);
  numBytes += cVar_init_f(&cVar_FQqxHGgV, 0.3f);
  numBytes += cBinop_init(&cBinop_SpV57ZQL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CmJxodvk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Sk2op25q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9VBG93U6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7WjoZOpx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Gzt10Ao6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_crBw0bnK, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_dUVwLzvD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_tMIBNR3g, 0.0f);
  numBytes += cVar_init_f(&cVar_L2id6emV, 1337.0f);
  numBytes += cVar_init_f(&cVar_U3dGxJfH, 0.313f);
  numBytes += cBinop_init(&cBinop_xJnB2QRp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_INWutskc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_K0INi9UX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_u7XMnkYM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_i3mLVp5z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xKy9FOUE, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_TWFxChhw, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_vd4VUsJp, 0.0f);
  numBytes += cVar_init_f(&cVar_tC7fUeIo, 1037.0f);
  numBytes += cVar_init_f(&cVar_SoxXjte3, 0.4f);
  numBytes += cBinop_init(&cBinop_CbbwbT1e, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TnIowIoc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nU9AsKmA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_H7DA8Qis, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_o2w1dbFi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uHhLH2aK, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_wNoIBwKQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zs78BUNw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_flWJofjf, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_zvAokxWU, 1, -1);
  numBytes += cVar_init_f(&cVar_KFVl6SEg, 1337.0f);
  numBytes += cVar_init_f(&cVar_dgAc46fG, 0.0f);
  numBytes += cIf_init(&cIf_CtyiGwaG, false);
  numBytes += cIf_init(&cIf_SOVtvV7d, false);
  numBytes += cBinop_init(&cBinop_GSdjPg12, 0.0f); // __pow
  numBytes += cIf_init(&cIf_6fl6phwV, false);
  numBytes += cBinop_init(&cBinop_AFwjZcIk, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_EGOomR1e, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_3sjsYxHd, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ygntg97b, 0.0f);
  numBytes += cIf_init(&cIf_GiKHy4o7, false);
  numBytes += cIf_init(&cIf_I42wFhWN, false);
  numBytes += cBinop_init(&cBinop_HsNN0I4K, 0.0f); // __pow
  numBytes += cIf_init(&cIf_y9spU39M, false);
  numBytes += cBinop_init(&cBinop_ZqSuPk45, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_7B106cjZ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_wy1eugEB, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_mVYKX3jp, 0.0f);
  numBytes += cIf_init(&cIf_VMoPfwB5, false);
  numBytes += cIf_init(&cIf_iwEqScJK, false);
  numBytes += cBinop_init(&cBinop_Y7uzRiSg, 0.0f); // __pow
  numBytes += cIf_init(&cIf_jnXuDYfn, false);
  numBytes += cBinop_init(&cBinop_OEcMKIBj, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_CLCbIvON, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Xmbcsy4W, -15.0f); // __eq
  numBytes += cIf_init(&cIf_l5anHsjp, false);
  numBytes += cSlice_init(&cSlice_ke3srxSC, 1, -1);
  numBytes += cVar_init_f(&cVar_U0QWk7PT, 0.0f);
  numBytes += cSlice_init(&cSlice_4mlt9kw3, 1, -1);
  numBytes += cVar_init_f(&cVar_7NQir8aM, 0.0f);
  numBytes += cSlice_init(&cSlice_ACRsowVX, 1, -1);
  numBytes += cVar_init_f(&cVar_GOoMHg8L, 0.0f);
  numBytes += cSlice_init(&cSlice_k9TPkZbD, 1, -1);
  numBytes += cVar_init_f(&cVar_FJZx45m5, 0.313f);
  numBytes += cBinop_init(&cBinop_XiBw2PBL, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_VD5ssbf2, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ByjtPJog, 0.0f);
  numBytes += cVar_init_f(&cVar_NIZqKC1c, 1337.0f);
  numBytes += cVar_init_f(&cVar_HwRJ1aDg, 0.3f);
  numBytes += cBinop_init(&cBinop_yCUyJSQT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tdzSXxSi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_02BR6lAt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tCS4U6gc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yHJWSt6d, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SSMGvCb3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JuMSppCj, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_02vzkJVe, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_hG3f0wug, 0.0f);
  numBytes += cVar_init_f(&cVar_DaXKJt2d, 1337.0f);
  numBytes += cVar_init_f(&cVar_LqfOrDu2, 0.313f);
  numBytes += cBinop_init(&cBinop_phB9ZDEA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mOEkGuLK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TOIYivRy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WGCSsTmw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bK0pmqi9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gdELYuNf, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_bb5qhsIv, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_PXg4fyYM, 0.0f);
  numBytes += cVar_init_f(&cVar_gDiVGir5, 1037.0f);
  numBytes += cVar_init_f(&cVar_S0By4Jqe, 0.4f);
  numBytes += cBinop_init(&cBinop_w0ZxiVXu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xI7GsVzV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cPU4Gu3C, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1LQXGraR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_O4b1KXbR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LWUjxRnD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_UujXhb5A, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UQ6Z4jbl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zixa8m1v, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_seZ4LRQs, 5705.6f);
  numBytes += cVar_init_f(&cVar_dipkrxb6, 313.3f);
  numBytes += cBinop_init(&cBinop_YUml3XsY, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_qu3FEt5P, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_9810lrn0, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2qoPdLQh_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ufrh7REf_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OOkM9S0f_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R8fFkXLC_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Gm9xtO86_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lXPujBcf_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TjoXp7oL_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fS9RpQGy_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pd1IpMrk_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7qKqy3Iu_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hRcu0yqk_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Alvr9y2c_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fjANCDGq_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vV7hKqs3_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VNpjjg3m_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_igeKPSNI_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Sy27vxn8_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sC2C6G0n_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZaU7LVji_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sEfNHEeb_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aRZYEWOw_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Am2L00Y4_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WYBQJFSY_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vw5uMln7_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bHLJvoCh_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_B0WlwGFQ_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7HwlqILa_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CWQtMage_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p3juSIWg_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lmudNx7C_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5cuq9JvA_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X8aYjjuO_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vUv9XndB_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_jfrtnOcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xrnNQ4bm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_IMR3H7Na_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lIYO0Ygn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_vtSy6wkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jlDRREMS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_1MtWumcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hFh2LvOU_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xl8n3231_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yFCE4lmN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BY9xw4Us_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_FDgSEzX9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_q4M7lqmQ, 0, m, &cSlice_q4M7lqmQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pqmi75R7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_q4M7lqmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IlOGYo3Q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IlOGYo3Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_E3GHwlih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IlOGYo3Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_IlOGYo3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TjoXp7oL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_v1gPC14f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vU1YdayI_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_jXkw23TC, 0, m, &cIf_jXkw23TC_sendMessage);
}

void Heavy_WSTD_3Q::cIf_jXkw23TC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8z3tGjPG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_xrOmesSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_fkYLArcn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_qlt901Pv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_qr3bW50C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ltKaGWx8, HV_BINOP_POW, 0, m, &cBinop_ltKaGWx8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ltKaGWx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uMjuheIM, 0, m, &cIf_uMjuheIM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_C55KkHdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_CswkOgFD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fkp1glzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zlYEXmCJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_f4OV2zQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xrOmesSp, 0, m, &cIf_xrOmesSp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zlYEXmCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xrOmesSp, 1, m, &cIf_xrOmesSp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qlt901Pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_C55KkHdG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_fkYLArcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_uMjuheIM, 0, m, &cIf_uMjuheIM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CswkOgFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ltKaGWx8, HV_BINOP_POW, 1, m, &cBinop_ltKaGWx8_sendMessage);
  cMsg_qr3bW50C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_uMjuheIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_wNoIBwKQ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_vU1YdayI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jXkw23TC, 1, m, &cIf_jXkw23TC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8z3tGjPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Cs4t5yp, HV_BINOP_GREATER_THAN, 1, m, &cBinop_7Cs4t5yp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FFv4Ln29, HV_BINOP_EQ, 1, m, &cBinop_FFv4Ln29_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_OQlGRDHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Id7mJvNd, HV_BINOP_ADD, 0, m, &cBinop_Id7mJvNd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Id7mJvNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fkp1glzG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f4OV2zQy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7Cs4t5yp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uMjuheIM, 1, m, &cIf_uMjuheIM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FFv4Ln29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jCSviFoJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_jCSviFoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wNoIBwKQ, m);
}

void Heavy_WSTD_3Q::cCast_JGjazFsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OQlGRDHa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_nnrBAPU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Id7mJvNd, HV_BINOP_ADD, 1, m, &cBinop_Id7mJvNd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Cs4t5yp, HV_BINOP_GREATER_THAN, 0, m, &cBinop_7Cs4t5yp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FFv4Ln29, HV_BINOP_EQ, 0, m, &cBinop_FFv4Ln29_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PTktNDQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v1gPC14f, 0, m, &cVar_v1gPC14f_sendMessage);
}

void Heavy_WSTD_3Q::cVar_UJUM10UO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_m1xhXQOD_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_majzE7Jd, 0, m, &cIf_majzE7Jd_sendMessage);
}

void Heavy_WSTD_3Q::cIf_majzE7Jd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xZkfSfhp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_ZJQF48kd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_QNtLfLDQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_md6VheIi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_iSTtLRFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vd918Vzh, HV_BINOP_POW, 0, m, &cBinop_Vd918Vzh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Vd918Vzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SNwc2YXi, 0, m, &cIf_SNwc2YXi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dMO9kBnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_P8Q2HXpV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yhjd5k4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZJQF48kd, 0, m, &cIf_ZJQF48kd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xiFwJol9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_54IOLCxB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_54IOLCxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZJQF48kd, 1, m, &cIf_ZJQF48kd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_md6VheIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dMO9kBnl_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_QNtLfLDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_SNwc2YXi, 0, m, &cIf_SNwc2YXi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_P8Q2HXpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vd918Vzh, HV_BINOP_POW, 1, m, &cBinop_Vd918Vzh_sendMessage);
  cMsg_iSTtLRFv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_SNwc2YXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vWwvK8fn_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8fe05WD0_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_eI5I2hpm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_m1xhXQOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_majzE7Jd, 1, m, &cIf_majzE7Jd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xZkfSfhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVwB3yXi, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bVwB3yXi_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E6Hm4A2S, HV_BINOP_EQ, 1, m, &cBinop_E6Hm4A2S_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Or2Jn0uW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ohOq4NCJ, HV_BINOP_ADD, 0, m, &cBinop_ohOq4NCJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ohOq4NCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xiFwJol9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yhjd5k4X_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bVwB3yXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SNwc2YXi, 1, m, &cIf_SNwc2YXi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_E6Hm4A2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U13FgygP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_U13FgygP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vWwvK8fn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8fe05WD0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_eI5I2hpm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XhmCYikg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UJUM10UO, 0, m, &cVar_UJUM10UO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_D5yZGYnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Or2Jn0uW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_Hllte5Ji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ohOq4NCJ, HV_BINOP_ADD, 1, m, &cBinop_ohOq4NCJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVwB3yXi, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bVwB3yXi_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E6Hm4A2S, HV_BINOP_EQ, 0, m, &cBinop_E6Hm4A2S_sendMessage);
}

void Heavy_WSTD_3Q::cVar_s7TeOLfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YORlybOH_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_kT6dfG4q, 0, m, &cIf_kT6dfG4q_sendMessage);
}

void Heavy_WSTD_3Q::cIf_kT6dfG4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_10bsZcHN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_nzIZIMff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_xrCi1UqH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_nWHELEnd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_xX8SjVIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NhNXhD8G, HV_BINOP_POW, 0, m, &cBinop_NhNXhD8G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NhNXhD8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tjyBEVR2, 0, m, &cIf_tjyBEVR2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_keUlqVr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8plgATOp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uD38lxc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nzIZIMff, 0, m, &cIf_nzIZIMff_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GUNo00M4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HR0bqPgL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HR0bqPgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nzIZIMff, 1, m, &cIf_nzIZIMff_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nWHELEnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_keUlqVr6_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_xrCi1UqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tjyBEVR2, 0, m, &cIf_tjyBEVR2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8plgATOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NhNXhD8G, HV_BINOP_POW, 1, m, &cBinop_NhNXhD8G_sendMessage);
  cMsg_xX8SjVIn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_tjyBEVR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_flWJofjf, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_YORlybOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kT6dfG4q, 1, m, &cIf_kT6dfG4q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_10bsZcHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OQ7VETJl, HV_BINOP_GREATER_THAN, 1, m, &cBinop_OQ7VETJl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gym5ehSH, HV_BINOP_EQ, 1, m, &cBinop_Gym5ehSH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_7SSIlkvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cAVDy5II, HV_BINOP_ADD, 0, m, &cBinop_cAVDy5II_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cAVDy5II_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GUNo00M4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uD38lxc9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OQ7VETJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tjyBEVR2, 1, m, &cIf_tjyBEVR2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Gym5ehSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qZTFOet4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_qZTFOet4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_flWJofjf, m);
}

void Heavy_WSTD_3Q::cCast_EXNZ7nCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s7TeOLfD, 0, m, &cVar_s7TeOLfD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nAnAPA9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7SSIlkvO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_nf3xSnxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cAVDy5II, HV_BINOP_ADD, 1, m, &cBinop_cAVDy5II_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OQ7VETJl, HV_BINOP_GREATER_THAN, 0, m, &cBinop_OQ7VETJl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gym5ehSH, HV_BINOP_EQ, 0, m, &cBinop_Gym5ehSH_sendMessage);
}

void Heavy_WSTD_3Q::cIf_dI4Lc73Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Zs78BUNw, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_NVp7adt5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8TuSeklC, 0, m, &cSlice_8TuSeklC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_W0grdQMj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_8TuSeklC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Mmjf8fah_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Mmjf8fah_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_ZlpDwMUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Mmjf8fah_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Mmjf8fah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Gm9xtO86_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_W0grdQMj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GcYg8prd, 0, m, &cSlice_GcYg8prd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FDgSEzX9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_GcYg8prd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BnET3vBI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BnET3vBI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_xnnLly9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BnET3vBI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_BnET3vBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pd1IpMrk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_pqmi75R7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DgRpcv9a, 0, m, &cSlice_DgRpcv9a_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4z2rXq2H_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_DgRpcv9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fTcprviX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fTcprviX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_2QfDry4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fTcprviX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_fTcprviX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lXPujBcf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_4z2rXq2H_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5n7kabDQ, 0, m, &cSlice_5n7kabDQ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_5n7kabDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JtFj4tCG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JtFj4tCG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_et2FBjua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JtFj4tCG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_JtFj4tCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fS9RpQGy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_idebMecT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eKj6bdJF, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Fvfwvqrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_14I7RrTz, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_k45sSNit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cR2N2yCy, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Q6crkC3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2nbteVhx, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_fK6rQSbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gGs7ipS6, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_jAI0jrq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uCdENDAN_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_uCdENDAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7TLfyVNP, HV_BINOP_DIVIDE, 1, m, &cBinop_7TLfyVNP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2S1bPDHy_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_jpcGnX86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_krkuEvX2_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_EONN58bQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jpcGnX86_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_krkuEvX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7TLfyVNP, HV_BINOP_DIVIDE, 0, m, &cBinop_7TLfyVNP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2S1bPDHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EONN58bQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_7TLfyVNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CMIBNTVT, HV_BINOP_MULTIPLY, 1, m, &cBinop_CMIBNTVT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CMIBNTVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4F1P11CV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d7041uNJ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_O2ET0YF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rexTbIL7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_LRhU6mv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Q4YS0JTo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_lQwClNeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Mt9dfKVQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Mt9dfKVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CMIBNTVT, HV_BINOP_MULTIPLY, 0, m, &cBinop_CMIBNTVT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gjEWr5lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_bvjCXTtJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bvjCXTtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jUiXXMez_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Lq66MIS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_khda2Ght, 1, m, &cVar_khda2Ght_sendMessage);
}

void Heavy_WSTD_3Q::cVar_khda2Ght_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_swKtxsuE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_pH3UXkH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CmJxodvk, HV_BINOP_MULTIPLY, 1, m, &cBinop_CmJxodvk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iy2gA8Xv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pH3UXkH3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ITd5WI4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UpvavH0W_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UpvavH0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sk2op25q, HV_BINOP_MULTIPLY, 1, m, &cBinop_Sk2op25q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jmLkgnGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9VBG93U6, HV_BINOP_MULTIPLY, 1, m, &cBinop_9VBG93U6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ENHOryIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jmLkgnGq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_O8KKQwcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7WjoZOpx, HV_BINOP_MULTIPLY, 1, m, &cBinop_7WjoZOpx_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_FDzdNmhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YktVAC59_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YktVAC59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gzt10Ao6, HV_BINOP_MULTIPLY, 1, m, &cBinop_Gzt10Ao6_sendMessage);
}

void Heavy_WSTD_3Q::cVar_etzAW6EM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z82hKKgx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_lQwClNeZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xgQ93EDV_sendMessage);
}

void Heavy_WSTD_3Q::cVar_FQqxHGgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gjEWr5lh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_d7041uNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_LRhU6mv3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4F1P11CV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_O2ET0YF3_sendMessage);
}

void Heavy_WSTD_3Q::cSend_rexTbIL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Alvr9y2c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Q4YS0JTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hRcu0yqk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_A3JIAblZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7qKqy3Iu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_jUiXXMez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_buSE3b9U_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_buSE3b9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SpV57ZQL, HV_BINOP_MULTIPLY, 1, m, &cBinop_SpV57ZQL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SpV57ZQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_P0kXceBl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_P0kXceBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_A3JIAblZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_swKtxsuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8Uc3vcto_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8Uc3vcto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7CH7fHYp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iqaduyrW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qjNwzjHd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z3k9fFh0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A0HI5tSI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6yb7jjyh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CmJxodvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_idebMecT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Sk2op25q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fvfwvqrx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9VBG93U6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k45sSNit_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_7WjoZOpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q6crkC3A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Gzt10Ao6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fK6rQSbL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_CrO7uqYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_etzAW6EM, 0, m, &cVar_etzAW6EM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kGbYcZAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FQqxHGgV, 1, m, &cVar_FQqxHGgV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_A0HI5tSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sk2op25q, HV_BINOP_MULTIPLY, 0, m, &cBinop_Sk2op25q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_z3k9fFh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9VBG93U6, HV_BINOP_MULTIPLY, 0, m, &cBinop_9VBG93U6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iqaduyrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gzt10Ao6, HV_BINOP_MULTIPLY, 0, m, &cBinop_Gzt10Ao6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6yb7jjyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CmJxodvk, HV_BINOP_MULTIPLY, 0, m, &cBinop_CmJxodvk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qjNwzjHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7WjoZOpx, HV_BINOP_MULTIPLY, 0, m, &cBinop_7WjoZOpx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7CH7fHYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_xgQ93EDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_khda2Ght, 0, m, &cVar_khda2Ght_sendMessage);
}

void Heavy_WSTD_3Q::cCast_z82hKKgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FQqxHGgV, 0, m, &cVar_FQqxHGgV_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_P5fnWNyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TWv9oRcT, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_QDYsYAAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P1kzTLzC, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_62R2wbQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NtA2PzBy, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Xlz3gntb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JsrjmH9I, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MGokEdL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7fOuGwHh_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_7fOuGwHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_crBw0bnK, HV_BINOP_DIVIDE, 1, m, &cBinop_crBw0bnK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uyyrqYaL_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Yt0rhTnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_FILC9uU7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_bLbdPYir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Yt0rhTnK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FILC9uU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_crBw0bnK, HV_BINOP_DIVIDE, 0, m, &cBinop_crBw0bnK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uyyrqYaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bLbdPYir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_crBw0bnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dUVwLzvD, HV_BINOP_MULTIPLY, 1, m, &cBinop_dUVwLzvD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dUVwLzvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4f2RkoVG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_06b5P3nP_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_secaQRzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uDTD82kq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_QqgnnLWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IWBr5ibq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_WaVctxhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_giAdiM5y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_giAdiM5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dUVwLzvD, HV_BINOP_MULTIPLY, 0, m, &cBinop_dUVwLzvD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XZZe0wyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_QD3eM94G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QD3eM94G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QpfYTHMI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6m3uOaw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K0INi9UX, HV_BINOP_MULTIPLY, 1, m, &cBinop_K0INi9UX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_B7Qc1UjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tMIBNR3g, 1, m, &cVar_tMIBNR3g_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1pbYYinU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u7XMnkYM, HV_BINOP_MULTIPLY, 1, m, &cBinop_u7XMnkYM_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_nUQHPKKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_d6r5YQHc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_d6r5YQHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i3mLVp5z, HV_BINOP_MULTIPLY, 1, m, &cBinop_i3mLVp5z_sendMessage);
}

void Heavy_WSTD_3Q::cVar_tMIBNR3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_APUTx5MC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_L2id6emV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A9cjyHKd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_WaVctxhE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SVDBrXrW_sendMessage);
}

void Heavy_WSTD_3Q::cVar_U3dGxJfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_XZZe0wyD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_06b5P3nP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_QqgnnLWw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4f2RkoVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_secaQRzU_sendMessage);
}

void Heavy_WSTD_3Q::cSend_uDTD82kq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VNpjjg3m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_IWBr5ibq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vV7hKqs3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_oYPnXQr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fjANCDGq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_QpfYTHMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_FSIGXJWd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FSIGXJWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xJnB2QRp, HV_BINOP_MULTIPLY, 1, m, &cBinop_xJnB2QRp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xJnB2QRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gWFEEBDO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gWFEEBDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oYPnXQr2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_APUTx5MC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_eFwvzZQC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eFwvzZQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cmg14sbh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SCujQoFm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GAnSHE9Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XZ68gUhK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_INWutskc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P5fnWNyc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_K0INi9UX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QDYsYAAX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_u7XMnkYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_62R2wbQD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_i3mLVp5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xlz3gntb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_zrqnLco2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_L2id6emV, 0, m, &cVar_L2id6emV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NjwCCN6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U3dGxJfH, 1, m, &cVar_U3dGxJfH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SVDBrXrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tMIBNR3g, 0, m, &cVar_tMIBNR3g_sendMessage);
}

void Heavy_WSTD_3Q::cCast_A9cjyHKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U3dGxJfH, 0, m, &cVar_U3dGxJfH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SCujQoFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u7XMnkYM, HV_BINOP_MULTIPLY, 0, m, &cBinop_u7XMnkYM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XZ68gUhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_INWutskc, HV_BINOP_MULTIPLY, 0, m, &cBinop_INWutskc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Cmg14sbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i3mLVp5z, HV_BINOP_MULTIPLY, 0, m, &cBinop_i3mLVp5z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GAnSHE9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K0INi9UX, HV_BINOP_MULTIPLY, 0, m, &cBinop_K0INi9UX_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_1euoV2DZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bx84acVu, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_VoVQ8Yan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ytgdm7By, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_hUFHPVkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aSzyrf1s, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_H7or9t4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8NJ3W0zf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ncUVaDPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gfUZVFTq, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_32oSRPDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_N9ALtUlu_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_N9ALtUlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xKy9FOUE, HV_BINOP_DIVIDE, 1, m, &cBinop_xKy9FOUE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0OfiC5bZ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_7FGrHqYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_iDTWjrLS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_MZzJTL8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_7FGrHqYi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iDTWjrLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xKy9FOUE, HV_BINOP_DIVIDE, 0, m, &cBinop_xKy9FOUE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0OfiC5bZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MZzJTL8m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xKy9FOUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TWFxChhw, HV_BINOP_MULTIPLY, 1, m, &cBinop_TWFxChhw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TWFxChhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GzCMn6UA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_beLnNjvR_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_F49U3vf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nNqtzkqL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_UxBPDM8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TMKIOnlx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_BBbX5NxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_20gJUaNR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_20gJUaNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TWFxChhw, HV_BINOP_MULTIPLY, 0, m, &cBinop_TWFxChhw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_i0puDkdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_aWIfLLrA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aWIfLLrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XTJgmyKK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_EIt07BVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TnIowIoc, HV_BINOP_MULTIPLY, 1, m, &cBinop_TnIowIoc_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_FQFAjXtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ayeaAQ3f_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ayeaAQ3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EIt07BVE_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Ai23OoXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FLQYtzGD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FLQYtzGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nU9AsKmA, HV_BINOP_MULTIPLY, 1, m, &cBinop_nU9AsKmA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pA9lTJNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H7DA8Qis, HV_BINOP_MULTIPLY, 1, m, &cBinop_H7DA8Qis_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_GbQbBNXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QLswgAjG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QLswgAjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pA9lTJNq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_moTOubIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vd4VUsJp, 1, m, &cVar_vd4VUsJp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bduJ7KAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o2w1dbFi, HV_BINOP_MULTIPLY, 1, m, &cBinop_o2w1dbFi_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4zuTdMwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oO3kzX87_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oO3kzX87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uHhLH2aK, HV_BINOP_MULTIPLY, 1, m, &cBinop_uHhLH2aK_sendMessage);
}

void Heavy_WSTD_3Q::cVar_vd4VUsJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L9tGKxsY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_tC7fUeIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AmCcAaTO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_BBbX5NxD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3wmz1SiT_sendMessage);
}

void Heavy_WSTD_3Q::cVar_SoxXjte3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_i0puDkdH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_beLnNjvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_UxBPDM8q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GzCMn6UA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_F49U3vf0_sendMessage);
}

void Heavy_WSTD_3Q::cSend_nNqtzkqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sC2C6G0n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_TMKIOnlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Sy27vxn8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_fA0LUSLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_igeKPSNI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_XTJgmyKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4umwPkI1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4umwPkI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CbbwbT1e, HV_BINOP_MULTIPLY, 1, m, &cBinop_CbbwbT1e_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CbbwbT1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NKapEe9o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NKapEe9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fA0LUSLb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_L9tGKxsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PHbWjzve_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PHbWjzve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mWGnlhar_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A8yRfwGW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pU6DdxcX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lCIfaQED_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qWHvs2z5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4Rl8fp5h_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TnIowIoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1euoV2DZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_nU9AsKmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VoVQ8Yan_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_H7DA8Qis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hUFHPVkH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_o2w1dbFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H7or9t4J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_uHhLH2aK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ncUVaDPw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_kbSKxFmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SoxXjte3, 1, m, &cVar_SoxXjte3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ovdKNu6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tC7fUeIo, 0, m, &cVar_tC7fUeIo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_A8yRfwGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uHhLH2aK, HV_BINOP_MULTIPLY, 0, m, &cBinop_uHhLH2aK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lCIfaQED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H7DA8Qis, HV_BINOP_MULTIPLY, 0, m, &cBinop_H7DA8Qis_sendMessage);
}

void Heavy_WSTD_3Q::cCast_pU6DdxcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o2w1dbFi, HV_BINOP_MULTIPLY, 0, m, &cBinop_o2w1dbFi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qWHvs2z5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nU9AsKmA, HV_BINOP_MULTIPLY, 0, m, &cBinop_nU9AsKmA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4Rl8fp5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TnIowIoc, HV_BINOP_MULTIPLY, 0, m, &cBinop_TnIowIoc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mWGnlhar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_3wmz1SiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vd4VUsJp, 0, m, &cVar_vd4VUsJp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AmCcAaTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SoxXjte3, 0, m, &cVar_SoxXjte3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vWwvK8fn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dI4Lc73Q, 1, m, &cIf_dI4Lc73Q_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_M2A2Sodc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Zs78BUNw, m);
}

void Heavy_WSTD_3Q::cBinop_8fe05WD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M2A2Sodc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_eI5I2hpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dI4Lc73Q, 0, m, &cIf_dI4Lc73Q_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_qmBjRVvS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zvAokxWU, 0, m, &cSlice_zvAokxWU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oPjUgda6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_zvAokxWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_l1ElyRjt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_l1ElyRjt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_KFVl6SEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_l1ElyRjt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_l1ElyRjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aRZYEWOw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_dgAc46fG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gakPBCgQ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_CtyiGwaG, 0, m, &cIf_CtyiGwaG_sendMessage);
}

void Heavy_WSTD_3Q::cIf_CtyiGwaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FEONa8WA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_SOVtvV7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_XrbdxU1E_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_vLC05DEs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_O7TlN3HM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GSdjPg12, HV_BINOP_POW, 0, m, &cBinop_GSdjPg12_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GSdjPg12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6fl6phwV, 0, m, &cIf_6fl6phwV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nC9o58EL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ioSIzLTZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_w0Ao3nDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SOVtvV7d, 0, m, &cIf_SOVtvV7d_sendMessage);
}

void Heavy_WSTD_3Q::cCast_b2j5MzNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8vfNZH0F_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8vfNZH0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SOVtvV7d, 1, m, &cIf_SOVtvV7d_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vLC05DEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_nC9o58EL_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_XrbdxU1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_6fl6phwV, 0, m, &cIf_6fl6phwV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ioSIzLTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GSdjPg12, HV_BINOP_POW, 1, m, &cBinop_GSdjPg12_sendMessage);
  cMsg_O7TlN3HM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_6fl6phwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_UujXhb5A, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_gakPBCgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CtyiGwaG, 1, m, &cIf_CtyiGwaG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FEONa8WA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EGOomR1e, HV_BINOP_GREATER_THAN, 1, m, &cBinop_EGOomR1e_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3sjsYxHd, HV_BINOP_EQ, 1, m, &cBinop_3sjsYxHd_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ORPtmvlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AFwjZcIk, HV_BINOP_ADD, 0, m, &cBinop_AFwjZcIk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AFwjZcIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b2j5MzNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w0Ao3nDK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EGOomR1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6fl6phwV, 1, m, &cIf_6fl6phwV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3sjsYxHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_250ukhWh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_250ukhWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UujXhb5A, m);
}

void Heavy_WSTD_3Q::cCast_WwCMK3Gn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ORPtmvlS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_atiZzxyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AFwjZcIk, HV_BINOP_ADD, 1, m, &cBinop_AFwjZcIk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EGOomR1e, HV_BINOP_GREATER_THAN, 0, m, &cBinop_EGOomR1e_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3sjsYxHd, HV_BINOP_EQ, 0, m, &cBinop_3sjsYxHd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_eCZ1PFyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dgAc46fG, 0, m, &cVar_dgAc46fG_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ygntg97b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MxhXmjev_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_GiKHy4o7, 0, m, &cIf_GiKHy4o7_sendMessage);
}

void Heavy_WSTD_3Q::cIf_GiKHy4o7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MX86cLdv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_I42wFhWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ZFJflXpe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_0HOPMHBO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_03J9eIiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HsNN0I4K, HV_BINOP_POW, 0, m, &cBinop_HsNN0I4K_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HsNN0I4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y9spU39M, 0, m, &cIf_y9spU39M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Uoxwkjgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_cb54gLE6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9caMjFHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_I42wFhWN, 0, m, &cIf_I42wFhWN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Zh5vYzs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MaFGW02v_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MaFGW02v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_I42wFhWN, 1, m, &cIf_I42wFhWN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0HOPMHBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Uoxwkjgf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZFJflXpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_y9spU39M, 0, m, &cIf_y9spU39M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cb54gLE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HsNN0I4K, HV_BINOP_POW, 1, m, &cBinop_HsNN0I4K_sendMessage);
  cMsg_03J9eIiG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_y9spU39M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9D42Yqs5_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_x3QjB3fx_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_mkGQinJ5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_MxhXmjev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GiKHy4o7, 1, m, &cIf_GiKHy4o7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MX86cLdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7B106cjZ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_7B106cjZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wy1eugEB, HV_BINOP_EQ, 1, m, &cBinop_wy1eugEB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_fjoDXAu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZqSuPk45, HV_BINOP_ADD, 0, m, &cBinop_ZqSuPk45_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZqSuPk45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zh5vYzs3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9caMjFHp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7B106cjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y9spU39M, 1, m, &cIf_y9spU39M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wy1eugEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U93HEhwg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_U93HEhwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9D42Yqs5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_x3QjB3fx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_mkGQinJ5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_62oNFfr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fjoDXAu7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_PfK78pLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ygntg97b, 0, m, &cVar_ygntg97b_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hGM9tyTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZqSuPk45, HV_BINOP_ADD, 1, m, &cBinop_ZqSuPk45_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7B106cjZ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_7B106cjZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wy1eugEB, HV_BINOP_EQ, 0, m, &cBinop_wy1eugEB_sendMessage);
}

void Heavy_WSTD_3Q::cVar_mVYKX3jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0nDl6kXL_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VMoPfwB5, 0, m, &cIf_VMoPfwB5_sendMessage);
}

void Heavy_WSTD_3Q::cIf_VMoPfwB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nvYEeXz4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_iwEqScJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_VA7lzOIY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_EYPVVvnD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_cnZ5UKBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y7uzRiSg, HV_BINOP_POW, 0, m, &cBinop_Y7uzRiSg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Y7uzRiSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jnXuDYfn, 0, m, &cIf_jnXuDYfn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HehK2ANx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_imAc98aq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KQh4lw8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iwEqScJK, 0, m, &cIf_iwEqScJK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cmUMBFnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BpVk2C7y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BpVk2C7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iwEqScJK, 1, m, &cIf_iwEqScJK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EYPVVvnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_HehK2ANx_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_VA7lzOIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_jnXuDYfn, 0, m, &cIf_jnXuDYfn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_imAc98aq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y7uzRiSg, HV_BINOP_POW, 1, m, &cBinop_Y7uzRiSg_sendMessage);
  cMsg_cnZ5UKBB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_jnXuDYfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_zixa8m1v, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_0nDl6kXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VMoPfwB5, 1, m, &cIf_VMoPfwB5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nvYEeXz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CLCbIvON, HV_BINOP_GREATER_THAN, 1, m, &cBinop_CLCbIvON_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xmbcsy4W, HV_BINOP_EQ, 1, m, &cBinop_Xmbcsy4W_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_G9cLReVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OEcMKIBj, HV_BINOP_ADD, 0, m, &cBinop_OEcMKIBj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OEcMKIBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cmUMBFnh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KQh4lw8l_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CLCbIvON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jnXuDYfn, 1, m, &cIf_jnXuDYfn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Xmbcsy4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zav9fxLA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_zav9fxLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zixa8m1v, m);
}

void Heavy_WSTD_3Q::cCast_CXC0BSL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mVYKX3jp, 0, m, &cVar_mVYKX3jp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MO5oYF1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OEcMKIBj, HV_BINOP_ADD, 1, m, &cBinop_OEcMKIBj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CLCbIvON, HV_BINOP_GREATER_THAN, 0, m, &cBinop_CLCbIvON_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xmbcsy4W, HV_BINOP_EQ, 0, m, &cBinop_Xmbcsy4W_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JnscY0Y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G9cLReVw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_l5anHsjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_UQ6Z4jbl, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_HhvlsgjL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ke3srxSC, 0, m, &cSlice_ke3srxSC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sImdb2Hk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_ke3srxSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NCPV5pZt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NCPV5pZt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_U0QWk7PT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NCPV5pZt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_NCPV5pZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZaU7LVji_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_sImdb2Hk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4mlt9kw3, 0, m, &cSlice_4mlt9kw3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qmBjRVvS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_4mlt9kw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0hLecjms_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0hLecjms_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_7NQir8aM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0hLecjms_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_0hLecjms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WYBQJFSY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_oPjUgda6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ACRsowVX, 0, m, &cSlice_ACRsowVX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hHkXcHIe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_ACRsowVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0xKSLa5g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0xKSLa5g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_GOoMHg8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0xKSLa5g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_0xKSLa5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sEfNHEeb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_hHkXcHIe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_k9TPkZbD, 0, m, &cSlice_k9TPkZbD_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_k9TPkZbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZuhBDs4W_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZuhBDs4W_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_FJZx45m5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZuhBDs4W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ZuhBDs4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Am2L00Y4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_dBbuB78I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8I98kIm3, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Tb9pL39I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lT7m5H5x, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Y6Kzl7E2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y3QPCsBr, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_K9RADPir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JRLhhLr5, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_GlxxXo5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yatRxkAG, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MqrbNxT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rrAYlWcd_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_rrAYlWcd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XiBw2PBL, HV_BINOP_DIVIDE, 1, m, &cBinop_XiBw2PBL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bKhO4fwp_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_lteRSIEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_SiSAUPl6_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZlnBulJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_lteRSIEe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SiSAUPl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XiBw2PBL, HV_BINOP_DIVIDE, 0, m, &cBinop_XiBw2PBL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bKhO4fwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZlnBulJI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_XiBw2PBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VD5ssbf2, HV_BINOP_MULTIPLY, 1, m, &cBinop_VD5ssbf2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VD5ssbf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5bANUX6K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K0tt5Wnr_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_zlgEpUxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8h94Flat_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_cRb4ILvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_w7F3X9x6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_bVouPOP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_GZHerVWn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GZHerVWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VD5ssbf2, HV_BINOP_MULTIPLY, 0, m, &cBinop_VD5ssbf2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fBAR8Ii0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_35QRjtTk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_35QRjtTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mNdFbusj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_stbcqS61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ByjtPJog, 1, m, &cVar_ByjtPJog_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ByjtPJog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uVfoupSk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_gl4bfnMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tdzSXxSi, HV_BINOP_MULTIPLY, 1, m, &cBinop_tdzSXxSi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ycc6tomW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gl4bfnMs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_capsYWxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TA64u9gh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TA64u9gh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_02BR6lAt, HV_BINOP_MULTIPLY, 1, m, &cBinop_02BR6lAt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EkWpuMg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tCS4U6gc, HV_BINOP_MULTIPLY, 1, m, &cBinop_tCS4U6gc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ckbYcVp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EkWpuMg6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ktSEtU1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yHJWSt6d, HV_BINOP_MULTIPLY, 1, m, &cBinop_yHJWSt6d_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_CcFAI29p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_INF2FBD9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_INF2FBD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SSMGvCb3, HV_BINOP_MULTIPLY, 1, m, &cBinop_SSMGvCb3_sendMessage);
}

void Heavy_WSTD_3Q::cVar_NIZqKC1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cu2COhpg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_bVouPOP5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZEW0bWGs_sendMessage);
}

void Heavy_WSTD_3Q::cVar_HwRJ1aDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_fBAR8Ii0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5bANUX6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_zlgEpUxT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_K0tt5Wnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_cRb4ILvt_sendMessage);
}

void Heavy_WSTD_3Q::cSend_8h94Flat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_B0WlwGFQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_w7F3X9x6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bHLJvoCh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_yPR6Stxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vw5uMln7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_mNdFbusj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_66aFzDdZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_66aFzDdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yCUyJSQT, HV_BINOP_MULTIPLY, 1, m, &cBinop_yCUyJSQT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yCUyJSQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_p0AjcL12_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_p0AjcL12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yPR6Stxt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_uVfoupSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_k6MYXm2O_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_k6MYXm2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZmMLDM8A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rJ85iH4r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ODjsWRFm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dNFOE809_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mWhxHnn8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dEyEwGFA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tdzSXxSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dBbuB78I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_02BR6lAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tb9pL39I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_tCS4U6gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y6Kzl7E2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_yHJWSt6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K9RADPir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SSMGvCb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GlxxXo5R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_Pesfzccl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NIZqKC1c, 0, m, &cVar_NIZqKC1c_sendMessage);
}

void Heavy_WSTD_3Q::cCast_i8Pt1SJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HwRJ1aDg, 1, m, &cVar_HwRJ1aDg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rJ85iH4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SSMGvCb3, HV_BINOP_MULTIPLY, 0, m, &cBinop_SSMGvCb3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mWhxHnn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_02BR6lAt, HV_BINOP_MULTIPLY, 0, m, &cBinop_02BR6lAt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dNFOE809_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tCS4U6gc, HV_BINOP_MULTIPLY, 0, m, &cBinop_tCS4U6gc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dEyEwGFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tdzSXxSi, HV_BINOP_MULTIPLY, 0, m, &cBinop_tdzSXxSi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ODjsWRFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yHJWSt6d, HV_BINOP_MULTIPLY, 0, m, &cBinop_yHJWSt6d_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZmMLDM8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_cu2COhpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HwRJ1aDg, 0, m, &cVar_HwRJ1aDg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZEW0bWGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ByjtPJog, 0, m, &cVar_ByjtPJog_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_YZh0Kmnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pbb7uhuO, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_7iPHrejT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hxjV1MJ2, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_8wv8KbtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KCcQEVnn, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_iu8kA44Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YDsfVvJx, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_0U5Uvbbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ikQiaKMs_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_ikQiaKMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JuMSppCj, HV_BINOP_DIVIDE, 1, m, &cBinop_JuMSppCj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oLcOuNlf_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_9hwDtK0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_tr6qCWIU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_um7gNDnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_9hwDtK0O_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tr6qCWIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JuMSppCj, HV_BINOP_DIVIDE, 0, m, &cBinop_JuMSppCj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_oLcOuNlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_um7gNDnH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_JuMSppCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_02vzkJVe, HV_BINOP_MULTIPLY, 1, m, &cBinop_02vzkJVe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_02vzkJVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ow7QsCT4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TdvyTqFZ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_mZ79iVZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8FTnTKKJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_EiqdLhT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_v3j1xT2L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xciwzv7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_4NJQhQdD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4NJQhQdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_02vzkJVe, HV_BINOP_MULTIPLY, 0, m, &cBinop_02vzkJVe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TSuk7cj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_miiK83JW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_miiK83JW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hFxIA5lf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_jWiuul9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TOIYivRy, HV_BINOP_MULTIPLY, 1, m, &cBinop_TOIYivRy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xCGgI05F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hG3f0wug, 1, m, &cVar_hG3f0wug_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_z14f1Wwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WGCSsTmw, HV_BINOP_MULTIPLY, 1, m, &cBinop_WGCSsTmw_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_TXl0zLry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rgQrqDbl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rgQrqDbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bK0pmqi9, HV_BINOP_MULTIPLY, 1, m, &cBinop_bK0pmqi9_sendMessage);
}

void Heavy_WSTD_3Q::cVar_hG3f0wug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BZJ2CChK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_DaXKJt2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KTN7GPoD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_xciwzv7h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VocsINDy_sendMessage);
}

void Heavy_WSTD_3Q::cVar_LqfOrDu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_TSuk7cj9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Ow7QsCT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_mZ79iVZH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TdvyTqFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_EiqdLhT3_sendMessage);
}

void Heavy_WSTD_3Q::cSend_8FTnTKKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_p3juSIWg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_v3j1xT2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CWQtMage_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_UrI3RKDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7HwlqILa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_hFxIA5lf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_D2xGOGSg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_D2xGOGSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_phB9ZDEA, HV_BINOP_MULTIPLY, 1, m, &cBinop_phB9ZDEA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_phB9ZDEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IJrTRWna_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IJrTRWna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UrI3RKDL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_BZJ2CChK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XuUzuch6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XuUzuch6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hv6WGFQZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xXN3zRjW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pYZNAeCj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6UATYqFO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mOEkGuLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YZh0Kmnz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_TOIYivRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7iPHrejT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_WGCSsTmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8wv8KbtI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_bK0pmqi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iu8kA44Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_ZhTl5Fug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DaXKJt2d, 0, m, &cVar_DaXKJt2d_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CE9RUrmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LqfOrDu2, 1, m, &cVar_LqfOrDu2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VocsINDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hG3f0wug, 0, m, &cVar_hG3f0wug_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KTN7GPoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LqfOrDu2, 0, m, &cVar_LqfOrDu2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Hv6WGFQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bK0pmqi9, HV_BINOP_MULTIPLY, 0, m, &cBinop_bK0pmqi9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6UATYqFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mOEkGuLK, HV_BINOP_MULTIPLY, 0, m, &cBinop_mOEkGuLK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xXN3zRjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WGCSsTmw, HV_BINOP_MULTIPLY, 0, m, &cBinop_WGCSsTmw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_pYZNAeCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TOIYivRy, HV_BINOP_MULTIPLY, 0, m, &cBinop_TOIYivRy_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_vTSlJwm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eiEWm6Dn, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xR2RKm1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kfjRbi8m, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_FgIJLMD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TkWBQdA2, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_wiaCCwJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HgB6s6ph, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_7kuz2zLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0Cl4HVxr, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_EDcSgDv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eULLxysw_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_eULLxysw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdELYuNf, HV_BINOP_DIVIDE, 1, m, &cBinop_gdELYuNf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YgKxeW3Q_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_F4UKxYL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_lw5LmAPw_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_FkscCLZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_F4UKxYL7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lw5LmAPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdELYuNf, HV_BINOP_DIVIDE, 0, m, &cBinop_gdELYuNf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YgKxeW3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FkscCLZz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_gdELYuNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bb5qhsIv, HV_BINOP_MULTIPLY, 1, m, &cBinop_bb5qhsIv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bb5qhsIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O1XTyP3l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_886OKzES_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_eKk1Uico_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uyy1Tyta_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_q1fcAhca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HFdZf353_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_eeq8eQVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_plaewexW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_plaewexW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bb5qhsIv, HV_BINOP_MULTIPLY, 0, m, &cBinop_bb5qhsIv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uH1Gxf1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_agHuH878_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_agHuH878_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gugqqsJA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1iuS0bHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xI7GsVzV, HV_BINOP_MULTIPLY, 1, m, &cBinop_xI7GsVzV_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_gT1t5upF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yXFh3gHg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yXFh3gHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1iuS0bHR_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_fmSONCWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BFDzG0LA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BFDzG0LA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cPU4Gu3C, HV_BINOP_MULTIPLY, 1, m, &cBinop_cPU4Gu3C_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ek5nvA9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1LQXGraR, HV_BINOP_MULTIPLY, 1, m, &cBinop_1LQXGraR_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_AROAhBMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6IUiQruK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6IUiQruK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ek5nvA9W_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dQ6DwjfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PXg4fyYM, 1, m, &cVar_PXg4fyYM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_knesFkqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O4b1KXbR, HV_BINOP_MULTIPLY, 1, m, &cBinop_O4b1KXbR_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Ys9OqKuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iOZZKIkP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iOZZKIkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LWUjxRnD, HV_BINOP_MULTIPLY, 1, m, &cBinop_LWUjxRnD_sendMessage);
}

void Heavy_WSTD_3Q::cVar_PXg4fyYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vbvV8ZF6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_gDiVGir5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ANInhJMy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_eeq8eQVv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hGPAF5Fw_sendMessage);
}

void Heavy_WSTD_3Q::cVar_S0By4Jqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_uH1Gxf1Q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_O1XTyP3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_eKk1Uico_sendMessage);
}

void Heavy_WSTD_3Q::cCast_886OKzES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_q1fcAhca_sendMessage);
}

void Heavy_WSTD_3Q::cSend_uyy1Tyta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_X8aYjjuO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_HFdZf353_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5cuq9JvA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_bfFuXP4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lmudNx7C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_gugqqsJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KAXymB8C_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KAXymB8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w0ZxiVXu, HV_BINOP_MULTIPLY, 1, m, &cBinop_w0ZxiVXu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_w0ZxiVXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2WeLuBUw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2WeLuBUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bfFuXP4Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_vbvV8ZF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rQ82WhbN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rQ82WhbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n07UuKRB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P7H64pH4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TyOEYjmb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hPe3tkSD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v3hgfL1W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mzQZW0L6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xI7GsVzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vTSlJwm2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_cPU4Gu3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xR2RKm1u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1LQXGraR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FgIJLMD9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_O4b1KXbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wiaCCwJx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LWUjxRnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7kuz2zLF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_DRCH1TIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S0By4Jqe, 1, m, &cVar_S0By4Jqe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5ItroLvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gDiVGir5, 0, m, &cVar_gDiVGir5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hPe3tkSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1LQXGraR, HV_BINOP_MULTIPLY, 0, m, &cBinop_1LQXGraR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_v3hgfL1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cPU4Gu3C, HV_BINOP_MULTIPLY, 0, m, &cBinop_cPU4Gu3C_sendMessage);
}

void Heavy_WSTD_3Q::cCast_n07UuKRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_P7H64pH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LWUjxRnD, HV_BINOP_MULTIPLY, 0, m, &cBinop_LWUjxRnD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mzQZW0L6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xI7GsVzV, HV_BINOP_MULTIPLY, 0, m, &cBinop_xI7GsVzV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TyOEYjmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O4b1KXbR, HV_BINOP_MULTIPLY, 0, m, &cBinop_O4b1KXbR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ANInhJMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S0By4Jqe, 0, m, &cVar_S0By4Jqe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hGPAF5Fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PXg4fyYM, 0, m, &cVar_PXg4fyYM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9D42Yqs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l5anHsjp, 1, m, &cIf_l5anHsjp_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_2GdB483E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UQ6Z4jbl, m);
}

void Heavy_WSTD_3Q::cBinop_x3QjB3fx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2GdB483E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_mkGQinJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l5anHsjp, 0, m, &cIf_l5anHsjp_sendMessage);
}

void Heavy_WSTD_3Q::cVar_seZ4LRQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qu3FEt5P, HV_BINOP_DIVIDE, 0, m, &cBinop_qu3FEt5P_sendMessage);
}

void Heavy_WSTD_3Q::cVar_dipkrxb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YUml3XsY, HV_BINOP_DIVIDE, 1, m, &cBinop_YUml3XsY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qu3FEt5P, HV_BINOP_DIVIDE, 1, m, &cBinop_qu3FEt5P_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_A0a0yoqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9810lrn0, HV_BINOP_DIVIDE, 0, m, &cBinop_9810lrn0_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_hjW7Bwwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9810lrn0, HV_BINOP_DIVIDE, 1, m, &cBinop_9810lrn0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BY9xw4Us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YUml3XsY, HV_BINOP_DIVIDE, 0, m, &cBinop_YUml3XsY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yFCE4lmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_seZ4LRQs, 0, m, &cVar_seZ4LRQs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xl8n3231_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dipkrxb6, 0, m, &cVar_dipkrxb6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YUml3XsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_A0a0yoqp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qu3FEt5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_hjW7Bwwe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9810lrn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_HSt5BbNR_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_k6bmhCfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_JpFwX6hb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FWSvJYEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_GIGQRKc3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HSt5BbNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FWSvJYEO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GIGQRKc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_k6bmhCfZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JpFwX6hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_REYmMQKz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_xrnNQ4bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NVp7adt5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HhvlsgjL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_lIYO0Ygn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NVp7adt5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HhvlsgjL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_jlDRREMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NVp7adt5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HhvlsgjL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_hFh2LvOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NVp7adt5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HhvlsgjL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_REYmMQKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NVp7adt5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_HhvlsgjL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_E6qekZAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_1MtWumcq, 0, m, &cVar_1MtWumcq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_zwqjnwvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_jfrtnOcP, 0, m, &cVar_jfrtnOcP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IMR3H7Na, 0, m, &cVar_IMR3H7Na_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vtSy6wkZ, 0, m, &cVar_vtSy6wkZ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_2qoPdLQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jfrtnOcP, 0, m, &cVar_jfrtnOcP_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_OOkM9S0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IMR3H7Na, 0, m, &cVar_IMR3H7Na_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Ufrh7REf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vtSy6wkZ, 0, m, &cVar_vtSy6wkZ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_TjoXp7oL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_L2id6emV, 0, m, &cVar_L2id6emV_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_fS9RpQGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NjwCCN6a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zrqnLco2_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Gm9xtO86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PTktNDQF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nnrBAPU2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JGjazFsK_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_lXPujBcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXNZ7nCk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nf3xSnxJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nAnAPA9W_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_pd1IpMrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XhmCYikg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hllte5Ji_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D5yZGYnV_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_vUv9XndB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jAI0jrq5_sendMessage(_c, 0, m);
  cMsg_MGokEdL4_sendMessage(_c, 0, m);
  cMsg_32oSRPDv_sendMessage(_c, 0, m);
  cMsg_MqrbNxT4_sendMessage(_c, 0, m);
  cMsg_0U5Uvbbn_sendMessage(_c, 0, m);
  cMsg_EDcSgDv2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_etzAW6EM, 0, m, &cVar_etzAW6EM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_L2id6emV, 0, m, &cVar_L2id6emV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tC7fUeIo, 0, m, &cVar_tC7fUeIo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NIZqKC1c, 0, m, &cVar_NIZqKC1c_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DaXKJt2d, 0, m, &cVar_DaXKJt2d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gDiVGir5, 0, m, &cVar_gDiVGir5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E3GHwlih, 0, m, &cVar_E3GHwlih_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v1gPC14f, 0, m, &cVar_v1gPC14f_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UJUM10UO, 0, m, &cVar_UJUM10UO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_s7TeOLfD, 0, m, &cVar_s7TeOLfD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZlpDwMUO, 0, m, &cVar_ZlpDwMUO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xnnLly9b, 0, m, &cVar_xnnLly9b_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2QfDry4G, 0, m, &cVar_2QfDry4G_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_et2FBjua, 0, m, &cVar_et2FBjua_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KFVl6SEg, 0, m, &cVar_KFVl6SEg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dgAc46fG, 0, m, &cVar_dgAc46fG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ygntg97b, 0, m, &cVar_ygntg97b_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mVYKX3jp, 0, m, &cVar_mVYKX3jp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_U0QWk7PT, 0, m, &cVar_U0QWk7PT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7NQir8aM, 0, m, &cVar_7NQir8aM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GOoMHg8L, 0, m, &cVar_GOoMHg8L_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FJZx45m5, 0, m, &cVar_FJZx45m5_sendMessage);
  cMsg_zwqjnwvD_sendMessage(_c, 0, m);
  cMsg_E6qekZAK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_Alvr9y2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SpV57ZQL, HV_BINOP_MULTIPLY, 0, m, &cBinop_SpV57ZQL_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_hRcu0yqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iy2gA8Xv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ITd5WI4C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ENHOryIr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_O8KKQwcY_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_7qKqy3Iu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Lq66MIS1_sendMessage);
  cMsg_FDzdNmhW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_VNpjjg3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xJnB2QRp, HV_BINOP_MULTIPLY, 0, m, &cBinop_xJnB2QRp_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_vV7hKqs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_1pbYYinU_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_fjANCDGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_INWutskc, HV_BINOP_MULTIPLY, 1, m, &cBinop_INWutskc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6m3uOaw2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_B7Qc1UjA_sendMessage);
  cMsg_nUQHPKKK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_sC2C6G0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CbbwbT1e, HV_BINOP_MULTIPLY, 0, m, &cBinop_CbbwbT1e_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Sy27vxn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FQFAjXtx_sendMessage(_c, 0, m);
  cMsg_Ai23OoXN_sendMessage(_c, 0, m);
  cMsg_GbQbBNXO_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_bduJ7KAs_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_igeKPSNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_moTOubIc_sendMessage);
  cMsg_4zuTdMwd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_aRZYEWOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DaXKJt2d, 0, m, &cVar_DaXKJt2d_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Am2L00Y4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CE9RUrmo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZhTl5Fug_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZaU7LVji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eCZ1PFyU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_atiZzxyK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WwCMK3Gn_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_sEfNHEeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CXC0BSL8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MO5oYF1W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JnscY0Y6_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_WYBQJFSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PfK78pLU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hGM9tyTG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_62oNFfr7_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_B0WlwGFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yCUyJSQT, HV_BINOP_MULTIPLY, 0, m, &cBinop_yCUyJSQT_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_bHLJvoCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ycc6tomW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_capsYWxP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ckbYcVp6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ktSEtU1z_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_vw5uMln7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_stbcqS61_sendMessage);
  cMsg_CcFAI29p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_p3juSIWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_phB9ZDEA, HV_BINOP_MULTIPLY, 0, m, &cBinop_phB9ZDEA_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_CWQtMage_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_z14f1Wwg_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_7HwlqILa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mOEkGuLK, HV_BINOP_MULTIPLY, 1, m, &cBinop_mOEkGuLK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jWiuul9q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xCGgI05F_sendMessage);
  cMsg_TXl0zLry_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_X8aYjjuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w0ZxiVXu, HV_BINOP_MULTIPLY, 0, m, &cBinop_w0ZxiVXu_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_5cuq9JvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gT1t5upF_sendMessage(_c, 0, m);
  cMsg_fmSONCWy_sendMessage(_c, 0, m);
  cMsg_AROAhBMh_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_knesFkqU_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_lmudNx7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dQ6DwjfU_sendMessage);
  cMsg_Ys9OqKuB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_R8fFkXLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1MtWumcq, 0, m, &cVar_1MtWumcq_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_eKj6bdJF, VOf(Bf0));
    __hv_line_f(&sLine_14I7RrTz, VOf(Bf1));
    __hv_line_f(&sLine_cR2N2yCy, VOf(Bf2));
    __hv_line_f(&sLine_2nbteVhx, VOf(Bf3));
    __hv_line_f(&sLine_gGs7ipS6, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_foWA1e5C, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_wNoIBwKQ, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_TWv9oRcT, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_P1kzTLzC, VOf(Bf1));
    __hv_line_f(&sLine_NtA2PzBy, VOf(Bf0));
    __hv_line_f(&sLine_JsrjmH9I, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_sVBgBtvZ, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_Zs78BUNw, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_Bx84acVu, VOf(Bf5));
    __hv_line_f(&sLine_ytgdm7By, VOf(Bf1));
    __hv_line_f(&sLine_aSzyrf1s, VOf(Bf2));
    __hv_line_f(&sLine_8NJ3W0zf, VOf(Bf4));
    __hv_line_f(&sLine_gfUZVFTq, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_gEY0feeB, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_flWJofjf, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_8I98kIm3, VOf(Bf6));
    __hv_line_f(&sLine_lT7m5H5x, VOf(Bf2));
    __hv_line_f(&sLine_y3QPCsBr, VOf(Bf1));
    __hv_line_f(&sLine_JRLhhLr5, VOf(Bf5));
    __hv_line_f(&sLine_yatRxkAG, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_HCG84Bua, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_UujXhb5A, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_pbb7uhuO, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_hxjV1MJ2, VOf(Bf2));
    __hv_line_f(&sLine_KCcQEVnn, VOf(Bf6));
    __hv_line_f(&sLine_YDsfVvJx, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_115TrxA1, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_UQ6Z4jbl, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_eiEWm6Dn, VOf(Bf8));
    __hv_line_f(&sLine_kfjRbi8m, VOf(Bf2));
    __hv_line_f(&sLine_TkWBQdA2, VOf(Bf1));
    __hv_line_f(&sLine_HgB6s6ph, VOf(Bf7));
    __hv_line_f(&sLine_0Cl4HVxr, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_dRi47Cya, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_zixa8m1v, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
